@@ -1,7 +1,7 @@
 package incus
 
 import (
-	"fmt"
+	"errors"
 	"net/http"
 )
 
@@ -14,6 +14,8 @@ type ProtocolOCI struct {
 
 	// Cache for images.
 	cache map[string]ociInfo
+
+	tempPath string
 }
 
 // Disconnect is a no-op for OCI.
@@ -34,7 +36,7 @@ func (r *ProtocolOCI) GetConnectionInfo() (*ConnectionInfo, error) {
 // GetHTTPClient returns the http client used for the connection. This can be used to set custom http options.
 func (r *ProtocolOCI) GetHTTPClient() (*http.Client, error) {
 	if r.http == nil {
-		return nil, fmt.Errorf("HTTP client isn't set, bad connection")
+		return nil, errors.New("HTTP client isn't set, bad connection")
 	}
 
 	return r.http, nil
