@@ -2,6 +2,7 @@ package main
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"net"
 	"testing"
@@ -306,7 +307,7 @@ func (suite *containerTestSuite) TestContainer_AddRoutedNicValidation() {
 		},
 		Name: "testFoo",
 	}, true)
-	suite.Req.NoError(err, fmt.Errorf("Adding multiple routed with gateway mode ['none'] should succeed. "))
+	suite.Req.NoError(err, errors.New("Adding multiple routed with gateway mode ['none'] should succeed. "))
 
 	eth0["ipv6.gateway"] = "auto"
 	eth1["ipv6.gateway"] = ""
@@ -321,7 +322,7 @@ func (suite *containerTestSuite) TestContainer_AddRoutedNicValidation() {
 		Name: "testFoo",
 	}, true)
 	suite.Req.Error(err,
-		fmt.Errorf("Adding multiple routed nic devices with any gateway mmode ['auto',''] should throw error. "))
+		errors.New("Adding multiple routed nic devices with any gateway mmode ['auto',''] should throw error. "))
 
 	err = c.Update(db.InstanceArgs{
 		Type:     instancetype.Container,
@@ -334,7 +335,7 @@ func (suite *containerTestSuite) TestContainer_AddRoutedNicValidation() {
 		Name: "testFoo",
 	}, true)
 	suite.Req.NoError(err,
-		fmt.Errorf("Adding multiple nic devices with unicque nictype ['routed'] should throw error. "))
+		errors.New("Adding multiple nic devices with unicque nictype ['routed'] should throw error. "))
 }
 
 func (suite *containerTestSuite) TestContainer_IsPrivileged_Unprivileged() {
@@ -398,13 +399,13 @@ func (suite *containerTestSuite) TestContainer_findIdmap_isolated() {
 
 	host := suite.d.os.IdmapSet.Entries[0]
 
-	for i := 0; i < 2; i++ {
+	for i := range 2 {
 		suite.Req.Equal(host.HostID+65536, map1.Entries[i].HostID, "hostids don't match %d", i)
 		suite.Req.Equal(int64(0), map1.Entries[i].NSID, "nsid nonzero")
 		suite.Req.Equal(int64(65536), map1.Entries[i].MapRange, "incorrect maprange")
 	}
 
-	for i := 0; i < 2; i++ {
+	for i := range 2 {
 		suite.Req.Equal(host.HostID+65536*2, map2.Entries[i].HostID, "hostids don't match")
 		suite.Req.Equal(int64(0), map2.Entries[i].NSID, "nsid nonzero")
 		suite.Req.Equal(int64(65536), map2.Entries[i].MapRange, "incorrect maprange")
@@ -441,13 +442,13 @@ func (suite *containerTestSuite) TestContainer_findIdmap_mixed() {
 
 	host := suite.d.os.IdmapSet.Entries[0]
 
-	for i := 0; i < 2; i++ {
+	for i := range 2 {
 		suite.Req.Equal(host.HostID, map1.Entries[i].HostID, "hostids don't match %d", i)
 		suite.Req.Equal(int64(0), map1.Entries[i].NSID, "nsid nonzero")
 		suite.Req.Equal(host.MapRange, map1.Entries[i].MapRange, "incorrect maprange")
 	}
 
-	for i := 0; i < 2; i++ {
+	for i := range 2 {
 		suite.Req.Equal(host.HostID+65536, map2.Entries[i].HostID, "hostids don't match")
 		suite.Req.Equal(int64(0), map2.Entries[i].NSID, "nsid nonzero")
 		suite.Req.Equal(int64(65536), map2.Entries[i].MapRange, "incorrect maprange")
@@ -492,7 +493,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_raw() {
 func (suite *containerTestSuite) TestContainer_findIdmap_maxed() {
 	maps := []*idmap.Set{}
 
-	for i := 0; i < 7; i++ {
+	for i := range 7 {
 		c, op, _, err := instance.CreateInternal(suite.d.State(), db.InstanceArgs{
 			Type: instancetype.Container,
 			Name: fmt.Sprintf("isol-%d", i),
@@ -532,5 +533,5 @@ func (suite *containerTestSuite) TestContainer_findIdmap_maxed() {
 }
 
 func TestContainerTestSuite(t *testing.T) {
-	suite.Run(t, new(containerTestSuite))
+	suite.Run(t, &containerTestSuite{})
 }
