@@ -1,7 +1,7 @@
 package main
 
 import (
-	"fmt"
+	"errors"
 	"io"
 	"net"
 	"os"
@@ -9,7 +9,7 @@ import (
 
 	"github.com/spf13/cobra"
 
-	"github.com/lxc/incus/internal/eagain"
+	"github.com/lxc/incus/v6/internal/eagain"
 )
 
 type cmdNetcat struct {
@@ -37,7 +37,7 @@ func (c *cmdNetcat) Run(cmd *cobra.Command, args []string) error {
 	// Handle mandatory arguments
 	if len(args) != 1 {
 		_ = cmd.Help()
-		return fmt.Errorf("Missing required argument")
+		return errors.New("Missing required argument")
 	}
 
 	// Connect to the provided address
