@@ -4,6 +4,10 @@ package request
 // notifying other nodes of a cluster change.
 const UserAgentNotifier = "incus-cluster-notifier"
 
+// UserAgentClient used to distinguish between a regular client request and an internal cluster request when
+// performing a regular API interaction as an internal client.
+const UserAgentClient = "incus-cluster-client"
+
 // UserAgentJoiner used to distinguish between a regular client request and an internal cluster request when
 // joining a node to a cluster.
 const UserAgentJoiner = "incus-cluster-joiner"
@@ -20,6 +24,9 @@ const ClientTypeJoiner ClientType = "joiner"
 // ClientTypeNormal normal client.
 const ClientTypeNormal ClientType = "normal"
 
+// ClientTypeInternal cluster internal client.
+const ClientTypeInternal ClientType = "internal"
+
 // UserAgentClientType converts user agent to client type.
 func UserAgentClientType(userAgent string) ClientType {
 	switch userAgent {
@@ -27,6 +34,8 @@ func UserAgentClientType(userAgent string) ClientType {
 		return ClientTypeNotifier
 	case UserAgentJoiner:
 		return ClientTypeJoiner
+	case UserAgentClient:
+		return ClientTypeInternal
 	}
 
 	return ClientTypeNormal
