@@ -139,11 +139,6 @@ func (list Devices) Update(newlist Devices, updateFields func(Device, Device) []
 
 	// Detect which devices have changed or been removed in in new list.
 	for key, d := range list {
-		// Always skip user keys.
-		if strings.HasPrefix(key, "user.") {
-			continue
-		}
-
 		if !newlist.Contains(key, d) {
 			rmlist[key] = d
 		}
@@ -151,11 +146,6 @@ func (list Devices) Update(newlist Devices, updateFields func(Device, Device) []
 
 	// Detect which devices have changed or been added in in new list.
 	for key, d := range newlist {
-		// Always skip user keys.
-		if strings.HasPrefix(key, "user.") {
-			continue
-		}
-
 		if !list.Contains(key, d) {
 			addlist[key] = d
 		}
@@ -172,6 +162,14 @@ func (list Devices) Update(newlist Devices, updateFields func(Device, Device) []
 		// Detect keys different between old and new device and append to the all changed keys list.
 		allChangedKeys = append(allChangedKeys, deviceEqualsDiffKeys(oldDevice, newDevice)...)
 
+		// Remove 'user.' fields that can be live-updated without adding/removing the device from instance.
+		for k := range d {
+			if strings.HasPrefix(k, "user.") {
+				delete(oldDevice, k)
+				delete(newDevice, k)
+			}
+		}
+
 		// Remove any fields that can be live-updated without adding/removing the device from instance.
 		if updateFields != nil {
 			for _, k := range updateFields(oldDevice, newDevice) {
