@@ -34,6 +34,7 @@ import (
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/idmap"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/osarch"
 	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/subprocess"
 	"github.com/lxc/incus/v6/shared/units"
@@ -160,6 +161,53 @@ func (d *disk) isRequired(devConfig deviceConfig.Device) bool {
 	return false
 }
 
+// isAvailable checks whether the source is currently available.
+func (d *disk) isAvailable() bool {
+	if d.config["pool"] == "" {
+		// We only check managed volumes.
+		return true
+	}
+
+	if d.config["path"] == "/" {
+		// Root disks are always considered available.
+		return true
+	}
+
+	// Load the pool if missing.
+	var err error
+	d.pool, err = storagePools.LoadByName(d.state, d.config["pool"])
+	if err != nil {
+		// If we can't load the pool, the volume isn't available.
+		return false
+	}
+
+	// We need instance data for further checks.
+	if d.inst == nil {
+		return true
+	}
+
+	// Check if the volume exists.
+	storageProjectName, err := project.StorageVolumeProject(d.state.DB.Cluster, d.inst.Project().Name, db.StoragePoolVolumeTypeCustom)
+	if err != nil {
+		return false
+	}
+
+	// Parse the volume name and path.
+	volName, _ := internalInstance.SplitVolumeSource(d.config["source"])
+
+	// GetStoragePoolVolume returns a volume with an empty Location field for remote drivers.
+	err = d.state.DB.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
+		_, err = tx.GetStoragePoolVolume(ctx, d.pool.ID(), storageProjectName, db.StoragePoolVolumeTypeCustom, volName, true)
+		return err
+	})
+	if err != nil {
+		return false
+	}
+
+	// We managed to get the entry from the database, consider it available.
+	return true
+}
+
 // sourceIsLocalPath returns true if the source supplied should be considered a local path on the host.
 // It returns false if the disk source is empty, a VM cloud-init config drive, or a remote ceph/cephfs path.
 func (d *disk) sourceIsLocalPath(source string) bool {
@@ -519,7 +567,7 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 		var dbVolume *db.StorageVolume
 		var storageProjectName string
 
-		if d.inst != nil && !d.inst.IsSnapshot() && d.config["source"] != "" && d.config["path"] != "/" {
+		if d.inst != nil && !d.inst.IsSnapshot() && d.config["source"] != "" && d.config["path"] != "/" && (d.isRequired(d.config) || d.isAvailable()) {
 			d.pool, err = storagePools.LoadByName(d.state, d.config["pool"])
 			if err != nil {
 				return fmt.Errorf("Failed to get storage pool %q: %w", d.config["pool"], err)
@@ -592,7 +640,7 @@ func (d *disk) validateConfig(instConf instance.ConfigReader) error {
 			}
 
 			// Custom volume validation.
-			if d.config["source"] != "" && d.config["path"] != "/" {
+			if d.config["source"] != "" && d.config["path"] != "/" && (d.isRequired(d.config) || d.isAvailable()) {
 				if storageProjectName == "" {
 					// Derive the effective storage project name from the instance config's project.
 					storageProjectName, err = project.StorageVolumeProject(d.state.DB.Cluster, instConf.Project().Name, db.StoragePoolVolumeTypeCustom)
@@ -869,7 +917,7 @@ func (d *disk) PreStartCheck() error {
 
 	// Custom volume disks that are not required don't need to be checked as if the pool is
 	// not available we should still start the instance.
-	if d.config["path"] != "/" && util.IsFalse(d.config["required"]) {
+	if d.config["path"] != "/" && !d.isRequired(d.config) {
 		return nil
 	}
 
@@ -883,6 +931,16 @@ func (d *disk) PreStartCheck() error {
 
 // Start is run when the device is added to the instance.
 func (d *disk) Start() (*deviceConfig.RunConfig, error) {
+	// Ignore detached disks.
+	if !util.IsTrueOrEmpty(d.config["attached"]) {
+		return nil, nil
+	}
+
+	// Ignore missing disks.
+	if !d.isRequired(d.config) && !d.isAvailable() {
+		return nil, nil
+	}
+
 	var runConfig *deviceConfig.RunConfig
 
 	err := d.validateEnvironment()
@@ -1240,9 +1298,6 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 		opts = append(opts, fmt.Sprintf("wwn=%s", d.config["wwn"]))
 	}
 
-	// Setup the attached status.
-	attached := util.IsTrueOrEmpty(d.config["attached"])
-
 	// Add I/O limits if set.
 	var diskLimits *deviceConfig.DiskLimits
 	if d.config["limits.read"] != "" || d.config["limits.write"] != "" || d.config["limits.max"] != "" {
@@ -1302,11 +1357,10 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 
 		// Encode the file descriptor and original isoPath into the DevPath field.
 		mount := deviceConfig.MountEntryItem{
-			DevPath:  fmt.Sprintf("%s:%d:%s", DiskFileDescriptorMountPrefix, f.Fd(), isoPath),
-			DevName:  d.name,
-			FSType:   "iso9660",
-			Opts:     opts,
-			Attached: attached,
+			DevPath: fmt.Sprintf("%s:%d:%s", DiskFileDescriptorMountPrefix, f.Fd(), isoPath),
+			DevName: d.name,
+			FSType:  "iso9660",
+			Opts:    opts,
 		}
 
 		err = d.setBus(&mount)
@@ -1337,11 +1391,10 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 
 		// Encode the file descriptor and original isoPath into the DevPath field.
 		mount := deviceConfig.MountEntryItem{
-			DevPath:  fmt.Sprintf("%s:%d:%s", DiskFileDescriptorMountPrefix, f.Fd(), isoPath),
-			DevName:  d.name,
-			FSType:   "iso9660",
-			Opts:     opts,
-			Attached: attached,
+			DevPath: fmt.Sprintf("%s:%d:%s", DiskFileDescriptorMountPrefix, f.Fd(), isoPath),
+			DevName: d.name,
+			FSType:  "iso9660",
+			Opts:    opts,
 		}
 
 		err = d.setBus(&mount)
@@ -1360,11 +1413,10 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 			fields = strings.SplitN(fields[1], "/", 2)
 			clusterName, userName := d.cephCreds()
 			mount := deviceConfig.MountEntryItem{
-				DevPath:  DiskGetRBDFormat(clusterName, userName, fields[0], fields[1]),
-				DevName:  d.name,
-				Opts:     opts,
-				Limits:   diskLimits,
-				Attached: attached,
+				DevPath: DiskGetRBDFormat(clusterName, userName, fields[0], fields[1]),
+				DevName: d.name,
+				Opts:    opts,
+				Limits:  diskLimits,
 			}
 
 			err := d.setBus(&mount)
@@ -1376,11 +1428,10 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 		} else {
 			// Default to block device or image file passthrough first.
 			mount := deviceConfig.MountEntryItem{
-				DevPath:  d.config["source"],
-				DevName:  d.name,
-				Opts:     opts,
-				Limits:   diskLimits,
-				Attached: attached,
+				DevPath: d.config["source"],
+				DevName: d.name,
+				Opts:    opts,
+				Limits:  diskLimits,
 			}
 
 			err := d.setBus(&mount)
@@ -1439,11 +1490,10 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 					}
 
 					mount := deviceConfig.MountEntryItem{
-						DevPath:  DiskGetRBDFormat(clusterName, userName, poolName, d.config["source"]),
-						DevName:  d.name,
-						Opts:     opts,
-						Limits:   diskLimits,
-						Attached: attached,
+						DevPath: DiskGetRBDFormat(clusterName, userName, poolName, d.config["source"]),
+						DevName: d.name,
+						Opts:    opts,
+						Limits:  diskLimits,
 					}
 
 					err = d.setBus(&mount)
@@ -1773,20 +1823,6 @@ func (d *disk) Update(oldDevices deviceConfig.Devices, isRunning bool) error {
 					Limits:  diskLimits,
 				})
 			}
-
-			oldAttached := util.IsTrueOrEmpty(oldDevices[d.name]["attached"])
-			newAttached := util.IsTrueOrEmpty(expandedDevices[d.name]["attached"])
-			if !oldAttached && newAttached {
-				runConf.Mounts = append(runConf.Mounts, deviceConfig.MountEntryItem{
-					DevName:  d.name,
-					Attached: true,
-				})
-			} else if oldAttached && !newAttached {
-				runConf.Mounts = append(runConf.Mounts, deviceConfig.MountEntryItem{
-					DevName:  d.name,
-					Attached: false,
-				})
-			}
 		}
 
 		err := d.inst.DeviceEventHandler(&runConf)
@@ -2129,6 +2165,17 @@ func (d *disk) createDevice(srcPath string) (func(), string, bool, error) {
 			srcPathFd := os.NewFile(uintptr(fd), volPath)
 			defer func() { _ = srcPathFd.Close() }()
 
+			// Check if the sub-path is a file or a directory.
+			fullSubPath := filepath.Join(srcPath, volPath)
+			volSubPathInfo, err := os.Stat(fullSubPath)
+			if err != nil {
+				return nil, "", false, fmt.Errorf("Failed accessing volume sub-path %q: %w", fullSubPath, err)
+			}
+
+			if !volSubPathInfo.IsDir() {
+				isFile = true
+			}
+
 			srcPath = fmt.Sprintf("/proc/self/fd/%d", srcPathFd.Fd())
 		}
 	}
@@ -2397,6 +2444,11 @@ func (d *disk) storagePoolVolumeAttachShift(projectName, poolName, volumeName st
 
 // Stop is run when the device is removed from the instance.
 func (d *disk) Stop() (*deviceConfig.RunConfig, error) {
+	// Ignore missing disks.
+	if !d.isRequired(d.config) && !d.isAvailable() {
+		return nil, nil
+	}
+
 	if d.inst.Type() == instancetype.VM {
 		return d.stopVM()
 	}
@@ -2891,17 +2943,23 @@ func (d *disk) generateVMAgentDrive() (string, error) {
 
 	// Include the most likely agent.
 	if util.PathExists(os.Getenv("INCUS_AGENT_PATH")) {
-		var srcFilename string
-		var dstFilename string
+		dstFilename := "incus-agent"
+		guestOS := d.inst.GuestOS()
 
-		if strings.Contains(strings.ToLower(d.inst.ExpandedConfig()["image.os"]), "windows") {
-			srcFilename = fmt.Sprintf("incus-agent.windows.%s", d.state.OS.Uname.Machine)
+		switch guestOS {
+		case "unknown":
+			guestOS = "linux"
+		case "windows":
 			dstFilename = "incus-agent.exe"
-		} else {
-			srcFilename = fmt.Sprintf("incus-agent.linux.%s", d.state.OS.Uname.Machine)
-			dstFilename = "incus-agent"
 		}
 
+		archName, err := osarch.ArchitectureName(d.inst.Architecture())
+		if err != nil {
+			return "", err
+		}
+
+		srcFilename := fmt.Sprintf("incus-agent.%s.%s", guestOS, archName)
+
 		agentInstallPath := filepath.Join(scratchDir, dstFilename)
 		os.Remove(agentInstallPath)
 
