@@ -44,7 +44,7 @@ func (d *nicRouted) UpdatableFields(oldDevice Type) []string {
 		return []string{}
 	}
 
-	return []string{"limits.ingress", "limits.egress", "limits.max", "limits.priority"}
+	return []string{"limits.ingress", "limits.egress", "limits.max", "limits.priority", "connected"}
 }
 
 // validateConfig checks the supplied config for correctness.
@@ -243,6 +243,24 @@ func (d *nicRouted) validateConfig(instConf instance.ConfigReader) error {
 		//  default: `virtio`
 		//  shortdesc: Override the bus for the device (can be `virtio` or `usb`) (VM only)
 		"io.bus",
+
+		// gendoc:generate(entity=devices, group=nic_routed, key=attached)
+		//
+		// ---
+		//  type: bool
+		//  default: `true`
+		//  required: no
+		//  shortdesc: Whether the NIC is plugged in or not
+		"attached",
+
+		// gendoc:generate(entity=devices, group=nic_routed, key=connected)
+		//
+		// ---
+		//  type: bool
+		//  default: `true`
+		//  required: no
+		//  shortdesc: Whether the NIC is connected to the host network
+		"connected",
 	}
 
 	rules := nicValidationRules(requiredFields, optionalFields, instConf)
@@ -467,6 +485,11 @@ func (d *nicRouted) checkIPAvailability(parent string) error {
 
 // Start is run when the instance is starting up (Routed mode doesn't support hot plugging).
 func (d *nicRouted) Start() (*deviceConfig.RunConfig, error) {
+	// Ignore detached NICs.
+	if !util.IsTrueOrEmpty(d.config["attached"]) {
+		return nil, nil
+	}
+
 	err := d.validateEnvironment()
 	if err != nil {
 		return nil, err
@@ -760,6 +783,7 @@ func (d *nicRouted) Start() (*deviceConfig.RunConfig, error) {
 		{Key: "flags", Value: "up"},
 		{Key: "link", Value: peerName},
 		{Key: "hwaddr", Value: d.config["hwaddr"]},
+		{Key: "connected", Value: d.config["connected"]},
 	}
 
 	if d.config["io.bus"] == "usb" {
@@ -856,6 +880,8 @@ func (d *nicRouted) Update(oldDevices deviceConfig.Devices, isRunning bool) erro
 		if err != nil {
 			return err
 		}
+
+		return d.setNICLink()
 	}
 
 	return nil
