@@ -3,6 +3,7 @@
 package device
 
 import (
+	"errors"
 	"fmt"
 	"strings"
 
@@ -98,7 +99,7 @@ func (d *unixHotplug) validateConfig(instConf instance.ConfigReader) error {
 	}
 
 	if d.config["vendorid"] == "" && d.config["productid"] == "" {
-		return fmt.Errorf("Unix hotplug devices require a vendorid or a productid")
+		return errors.New("Unix hotplug devices require a vendorid or a productid")
 	}
 
 	return nil
@@ -139,6 +140,10 @@ func (d *unixHotplug) Register() error {
 			if err != nil {
 				return nil, err
 			}
+			// Return early to prevent injecting duplicate uevents.
+			if len(runConf.Mounts) == 0 {
+				return nil, nil
+			}
 
 			// Add a post hook function to remove the specific unix hotplug device file after unmount.
 			runConf.PostHooks = []func() error{func() error {
@@ -168,7 +173,7 @@ func (d *unixHotplug) Start() (*deviceConfig.RunConfig, error) {
 
 	device := d.loadUnixDevice()
 	if d.isRequired() && device == nil {
-		return nil, fmt.Errorf("Required Unix Hotplug device not found")
+		return nil, errors.New("Required Unix Hotplug device not found")
 	}
 
 	if device == nil {
