@@ -5,15 +5,13 @@ import (
 	"crypto/rand"
 	"crypto/rsa"
 	"errors"
-	"fmt"
 	"math/big"
 	"strings"
 	"sync"
 	"time"
 
-	jose "github.com/go-jose/go-jose/v3"
+	jose "github.com/go-jose/go-jose/v4"
 	"github.com/google/uuid"
-
 	"github.com/zitadel/oidc/v3/pkg/oidc"
 	"github.com/zitadel/oidc/v3/pkg/op"
 )
@@ -37,18 +35,20 @@ var (
 // typically you would implement this as a layer on top of your database
 // for simplicity this example keeps everything in-memory
 type Storage struct {
-	lock          sync.Mutex
-	authRequests  map[string]*AuthRequest
-	codes         map[string]string
-	tokens        map[string]*Token
-	clients       map[string]*Client
-	userStore     UserStore
-	services      map[string]Service
-	refreshTokens map[string]*RefreshToken
-	signingKey    signingKey
-	deviceCodes   map[string]deviceAuthorizationEntry
-	userCodes     map[string]string
-	serviceUsers  map[string]*Client
+	lock                   sync.Mutex
+	authRequests           map[string]*AuthRequest
+	codes                  map[string]string
+	tokens                 map[string]*Token
+	clients                map[string]*Client
+	userStore              UserStore
+	services               map[string]Service
+	refreshTokens          map[string]*RefreshToken
+	signingKey             signingKey
+	deviceCodes            map[string]deviceAuthorizationEntry
+	userCodes              map[string]string
+	serviceUsers           map[string]*Client
+	accessTokenExpiration  time.Duration
+	refreshTokenExpiration time.Duration
 }
 
 type signingKey struct {
@@ -89,9 +89,23 @@ func (s *publicKey) Key() any {
 	return &s.key.PublicKey
 }
 
-func NewStorage(userStore UserStore) *Storage {
+type Option func(storage *Storage)
+
+func WithAccessTokenExpiration(expiration time.Duration) Option {
+	return func(storage *Storage) {
+		storage.accessTokenExpiration = expiration
+	}
+}
+
+func WithRefreshTokenExpiration(expiration time.Duration) Option {
+	return func(storage *Storage) {
+		storage.refreshTokenExpiration = expiration
+	}
+}
+
+func NewStorage(userStore UserStore, opts ...Option) *Storage {
 	key, _ := rsa.GenerateKey(rand.Reader, 2048)
-	return &Storage{
+	storage := &Storage{
 		authRequests:  make(map[string]*AuthRequest),
 		codes:         make(map[string]string),
 		tokens:        make(map[string]*Token),
@@ -122,7 +136,15 @@ func NewStorage(userStore UserStore) *Storage {
 				accessTokenType: op.AccessTokenTypeBearer,
 			},
 		},
+		accessTokenExpiration:  5 * time.Minute,
+		refreshTokenExpiration: 5 * time.Hour,
 	}
+
+	for _, opt := range opts {
+		opt(storage)
+	}
+
+	return storage
 }
 
 // CheckUsernamePassword implements the `authenticate` interface of the login
@@ -131,7 +153,7 @@ func (s *Storage) CheckUsernamePassword(username, password, id string) error {
 	defer s.lock.Unlock()
 	request, ok := s.authRequests[id]
 	if !ok {
-		return fmt.Errorf("request not found")
+		return errors.New("request not found")
 	}
 
 	// for demonstration purposes we'll check we'll have a simple user store and
@@ -149,7 +171,7 @@ func (s *Storage) CheckUsernamePassword(username, password, id string) error {
 		request.done = true
 		return nil
 	}
-	return fmt.Errorf("username or password wrong")
+	return errors.New("username or password wrong")
 }
 
 func (s *Storage) CheckUsernamePasswordSimple(username, password string) error {
@@ -160,7 +182,7 @@ func (s *Storage) CheckUsernamePasswordSimple(username, password string) error {
 	if user != nil && user.Password == password {
 		return nil
 	}
-	return fmt.Errorf("username or password wrong")
+	return errors.New("username or password wrong")
 }
 
 // CreateAuthRequest implements the op.Storage interface
@@ -195,7 +217,7 @@ func (s *Storage) AuthRequestByID(ctx context.Context, id string) (op.AuthReques
 	defer s.lock.Unlock()
 	request, ok := s.authRequests[id]
 	if !ok {
-		return nil, fmt.Errorf("request not found")
+		return nil, errors.New("request not found")
 	}
 	return request, nil
 }
@@ -211,7 +233,7 @@ func (s *Storage) AuthRequestByCode(ctx context.Context, code string) (op.AuthRe
 		return requestID, ok
 	}()
 	if !ok {
-		return nil, fmt.Errorf("code invalid or expired")
+		return nil, errors.New("code invalid or expired")
 	}
 	return s.AuthRequestByID(ctx, requestID)
 }
@@ -327,7 +349,7 @@ func (s *Storage) TokenRequestByRefreshToken(ctx context.Context, refreshToken s
 	defer s.lock.Unlock()
 	token, ok := s.refreshTokens[refreshToken]
 	if !ok {
-		return nil, fmt.Errorf("invalid refresh_token")
+		return nil, errors.New("invalid refresh_token")
 	}
 	return RefreshTokenRequestFromBusiness(token), nil
 }
@@ -424,7 +446,7 @@ func (s *Storage) GetClientByClientID(ctx context.Context, clientID string) (op.
 	defer s.lock.Unlock()
 	client, ok := s.clients[clientID]
 	if !ok {
-		return nil, fmt.Errorf("client not found")
+		return nil, errors.New("client not found")
 	}
 	return RedirectGlobsClient(client), nil
 }
@@ -436,12 +458,12 @@ func (s *Storage) AuthorizeClientIDSecret(ctx context.Context, clientID, clientS
 	defer s.lock.Unlock()
 	client, ok := s.clients[clientID]
 	if !ok {
-		return fmt.Errorf("client not found")
+		return errors.New("client not found")
 	}
 	// for this example we directly check the secret
 	// obviously you would not have the secret in plain text, but rather hashed and salted (e.g. using bcrypt)
 	if client.secret != clientSecret {
-		return fmt.Errorf("invalid secret")
+		return errors.New("invalid secret")
 	}
 	return nil
 }
@@ -469,7 +491,7 @@ func (s *Storage) SetUserinfoFromToken(ctx context.Context, userinfo *oidc.UserI
 		return token, ok
 	}()
 	if !ok {
-		return fmt.Errorf("token is invalid or has expired")
+		return errors.New("token is invalid or has expired")
 	}
 	// the userinfo endpoint should support CORS. If it's not possible to specify a specific origin in the CORS handler,
 	// and you have to specify a wildcard (*) origin, then you could also check here if the origin which called the userinfo endpoint here directly
@@ -478,7 +500,7 @@ func (s *Storage) SetUserinfoFromToken(ctx context.Context, userinfo *oidc.UserI
 	// if origin != "" {
 	//	client, ok := s.clients[token.ApplicationID]
 	//	if !ok {
-	//		return fmt.Errorf("client not found")
+	//		return errors.New("client not found")
 	//	}
 	//	if err := checkAllowedOrigins(client.allowedOrigins, origin); err != nil {
 	//		return err
@@ -497,7 +519,7 @@ func (s *Storage) SetIntrospectionFromToken(ctx context.Context, introspection *
 		return token, ok
 	}()
 	if !ok {
-		return fmt.Errorf("token is invalid or has expired")
+		return errors.New("token is invalid or has expired")
 	}
 	// check if the client is part of the requested audience
 	for _, aud := range token.Audience {
@@ -520,7 +542,7 @@ func (s *Storage) SetIntrospectionFromToken(ctx context.Context, introspection *
 			return nil
 		}
 	}
-	return fmt.Errorf("token is not valid for this client")
+	return errors.New("token is not valid for this client")
 }
 
 // GetPrivateClaimsFromScopes implements the op.Storage interface
@@ -546,11 +568,11 @@ func (s *Storage) GetKeyByIDAndClientID(ctx context.Context, keyID, clientID str
 	defer s.lock.Unlock()
 	service, ok := s.services[clientID]
 	if !ok {
-		return nil, fmt.Errorf("clientID not found")
+		return nil, errors.New("clientID not found")
 	}
 	key, ok := service.keys[keyID]
 	if !ok {
-		return nil, fmt.Errorf("key not found")
+		return nil, errors.New("key not found")
 	}
 	return &jose.JSONWebKey{
 		KeyID: keyID,
@@ -588,7 +610,7 @@ func (s *Storage) createRefreshToken(accessToken *Token, amr []string, authTime
 		ApplicationID: accessToken.ApplicationID,
 		UserID:        accessToken.Subject,
 		Audience:      accessToken.Audience,
-		Expiration:    time.Now().Add(5 * time.Hour),
+		Expiration:    time.Now().Add(s.refreshTokenExpiration),
 		Scopes:        accessToken.Scopes,
 	}
 	s.refreshTokens[token.ID] = token
@@ -601,7 +623,7 @@ func (s *Storage) renewRefreshToken(currentRefreshToken string) (string, string,
 	defer s.lock.Unlock()
 	refreshToken, ok := s.refreshTokens[currentRefreshToken]
 	if !ok {
-		return "", "", fmt.Errorf("invalid refresh token")
+		return "", "", errors.New("invalid refresh token")
 	}
 	// deletes the refresh token and all access tokens which were issued based on this refresh token
 	delete(s.refreshTokens, currentRefreshToken)
@@ -629,7 +651,7 @@ func (s *Storage) accessToken(applicationID, refreshTokenID, subject string, aud
 		RefreshTokenID: refreshTokenID,
 		Subject:        subject,
 		Audience:       audience,
-		Expiration:     time.Now().Add(5 * time.Minute),
+		Expiration:     time.Now().Add(s.accessTokenExpiration),
 		Scopes:         scopes,
 	}
 	s.tokens[token.ID] = token
@@ -642,7 +664,7 @@ func (s *Storage) setUserinfo(ctx context.Context, userInfo *oidc.UserInfo, user
 	defer s.lock.Unlock()
 	user := s.userStore.GetUserByID(userID)
 	if user == nil {
-		return fmt.Errorf("user not found")
+		return errors.New("user not found")
 	}
 	for _, scope := range scopes {
 		switch scope {
@@ -659,7 +681,7 @@ func (s *Storage) setUserinfo(ctx context.Context, userInfo *oidc.UserInfo, user
 			userInfo.Locale = oidc.NewLocale(user.PreferredLanguage)
 		case oidc.ScopePhone:
 			userInfo.PhoneNumber = user.Phone
-			userInfo.PhoneNumberVerified = user.PhoneVerified
+			userInfo.PhoneNumberVerified = oidc.Bool(user.PhoneVerified)
 		case CustomScope:
 			// you can also have a custom scope and assert public or custom claims based on that
 			userInfo.AppendClaims(CustomClaim, customClaim(clientID))
@@ -691,8 +713,9 @@ func (s *Storage) ValidateTokenExchangeRequest(ctx context.Context, request op.T
 			continue
 		}
 
-		if strings.HasPrefix(scope, CustomScopeImpersonatePrefix) {
-			subject := strings.TrimPrefix(scope, CustomScopeImpersonatePrefix)
+		after, ok := strings.CutPrefix(scope, CustomScopeImpersonatePrefix)
+		if ok {
+			subject := after
 			request.SetSubject(subject)
 		}
 
@@ -765,14 +788,17 @@ func (s *Storage) getTokenExchangeClaims(ctx context.Context, request op.TokenEx
 
 // getInfoFromRequest returns the clientID, authTime and amr depending on the op.TokenRequest type / implementation
 func getInfoFromRequest(req op.TokenRequest) (clientID string, authTime time.Time, amr []string) {
-	authReq, ok := req.(*AuthRequest) // Code Flow (with scope offline_access)
-	if ok {
-		return authReq.ApplicationID, authReq.authTime, authReq.GetAMR()
-	}
-	refreshReq, ok := req.(*RefreshTokenRequest) // Refresh Token Request
-	if ok {
-		return refreshReq.ApplicationID, refreshReq.AuthTime, refreshReq.AMR
+	switch r := req.(type) {
+	case *AuthRequest: // Code Flow (with scope offline_access)
+		return r.ApplicationID, r.authTime, r.GetAMR()
+
+	case *RefreshTokenRequest: // Refresh Token Request
+		return r.ApplicationID, r.AuthTime, r.AMR
+
+	case *op.DeviceAuthorizationState: // Device Code Flow
+		return r.ClientID, r.AuthTime, r.GetAMR()
 	}
+
 	return "", time.Time{}, nil
 }
 
